@@ -24,6 +24,8 @@
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/collection.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 
 
 
@@ -32,23 +34,29 @@ struct _ValaCCodeFunctionDeclaratorPrivate {
 	char* _name;
 	GeeList* parameters;
 };
+
 #define VALA_CCODE_FUNCTION_DECLARATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION_DECLARATOR, ValaCCodeFunctionDeclaratorPrivate))
 enum  {
-	VALA_CCODE_FUNCTION_DECLARATOR_DUMMY_PROPERTY,
-	VALA_CCODE_FUNCTION_DECLARATOR_NAME
+	VALA_CCODE_FUNCTION_DECLARATOR_DUMMY_PROPERTY
 };
 static void vala_ccode_function_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_function_declarator_parent_class = NULL;
-static void vala_ccode_function_declarator_dispose (GObject * obj);
+static void vala_ccode_function_declarator_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_construct (GType object_type, const char* name) {
+	ValaCCodeFunctionDeclarator* self;
+	g_return_val_if_fail (name != NULL, NULL);
+	self = (ValaCCodeFunctionDeclarator*) g_type_create_instance (object_type);
+	vala_ccode_function_declarator_set_name (self, name);
+	return self;
+}
+
+
 ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* name) {
-	ValaCCodeFunctionDeclarator * self;
-	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_DECLARATOR, 0, NULL);
-	vala_ccode_function_declarator_set_name (self, name);
-	return self;
+	return vala_ccode_function_declarator_construct (VALA_TYPE_CCODE_FUNCTION_DECLARATOR, name);
 }
 
 
@@ -58,55 +66,51 @@ ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* nam
  * @param param a formal parameter
  */
 void vala_ccode_function_declarator_add_parameter (ValaCCodeFunctionDeclarator* self, ValaCCodeFormalParameter* param) {
-	g_return_if_fail (VALA_IS_CCODE_FUNCTION_DECLARATOR (self));
-	g_return_if_fail (param == NULL || VALA_IS_CCODE_FORMAL_PARAMETER (param));
-	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (param != NULL);
+	gee_collection_add ((GeeCollection*) self->priv->parameters, param);
 }
 
 
 static void vala_ccode_function_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFunctionDeclarator * self;
-	self = VALA_CCODE_FUNCTION_DECLARATOR (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_node_write_declaration (VALA_CCODE_NODE (self), writer);
+	self = (ValaCCodeFunctionDeclarator*) base;
+	g_return_if_fail (writer != NULL);
+	vala_ccode_node_write_declaration ((ValaCCodeNode*) self, writer);
 }
 
 
 static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFunctionDeclarator * self;
 	gboolean first;
-	self = VALA_CCODE_FUNCTION_DECLARATOR (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	self = (ValaCCodeFunctionDeclarator*) base;
+	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_string (writer, "(*");
 	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, ") (");
 	first = TRUE;
 	{
-		GeeList* param_collection;
 		GeeIterator* param_it;
-		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
 		while (gee_iterator_next (param_it)) {
 			ValaCCodeFormalParameter* param;
-			param = ((ValaCCodeFormalParameter*) gee_iterator_get (param_it));
-			{
-				if (!first) {
-					vala_ccode_writer_write_string (writer, ", ");
-				} else {
-					first = FALSE;
-				}
-				vala_ccode_node_write (VALA_CCODE_NODE (param), writer);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+			param = (ValaCCodeFormalParameter*) gee_iterator_get (param_it);
+			if (!first) {
+				vala_ccode_writer_write_string (writer, ", ");
+			} else {
+				first = FALSE;
 			}
+			vala_ccode_node_write ((ValaCCodeNode*) param, writer);
+			(param == NULL) ? NULL : (param = (vala_ccode_node_unref (param), NULL));
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
+		(param_it == NULL) ? NULL : (param_it = (gee_collection_object_unref (param_it), NULL));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
 
 
-char* vala_ccode_function_declarator_get_name (ValaCCodeFunctionDeclarator* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_DECLARATOR (self), NULL);
+const char* vala_ccode_function_declarator_get_name (ValaCCodeFunctionDeclarator* self) {
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_name;
 }
 
@@ -114,72 +118,41 @@ char* vala_ccode_function_declarator_get_name (ValaCCodeFunctionDeclarator* self
 void vala_ccode_function_declarator_set_name (ValaCCodeFunctionDeclarator* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_FUNCTION_DECLARATOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-}
-
-
-static void vala_ccode_function_declarator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunctionDeclarator * self;
-	self = VALA_CCODE_FUNCTION_DECLARATOR (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_DECLARATOR_NAME:
-		g_value_set_string (value, vala_ccode_function_declarator_get_name (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_function_declarator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunctionDeclarator * self;
-	self = VALA_CCODE_FUNCTION_DECLARATOR (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_DECLARATOR_NAME:
-		vala_ccode_function_declarator_set_name (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
 }
 
 
 static void vala_ccode_function_declarator_class_init (ValaCCodeFunctionDeclaratorClass * klass) {
 	vala_ccode_function_declarator_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_function_declarator_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeFunctionDeclaratorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_function_declarator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_function_declarator_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_function_declarator_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_declarator_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_function_declarator_real_write_declaration;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_DECLARATOR_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_function_declarator_init (ValaCCodeFunctionDeclarator * self) {
+static void vala_ccode_function_declarator_instance_init (ValaCCodeFunctionDeclarator * self) {
 	self->priv = VALA_CCODE_FUNCTION_DECLARATOR_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->parameters = (GeeList*) gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, (GBoxedCopyFunc) vala_ccode_node_ref, vala_ccode_node_unref, g_direct_equal);
 }
 
 
-static void vala_ccode_function_declarator_dispose (GObject * obj) {
+static void vala_ccode_function_declarator_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFunctionDeclarator * self;
 	self = VALA_CCODE_FUNCTION_DECLARATOR (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	G_OBJECT_CLASS (vala_ccode_function_declarator_parent_class)->dispose (obj);
+	(self->priv->parameters == NULL) ? NULL : (self->priv->parameters = (gee_collection_object_unref (self->priv->parameters), NULL));
+	VALA_CCODE_NODE_CLASS (vala_ccode_function_declarator_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_function_declarator_get_type (void) {
 	static GType vala_ccode_function_declarator_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_function_declarator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionDeclarator), 0, (GInstanceInitFunc) vala_ccode_function_declarator_init };
+	if (vala_ccode_function_declarator_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionDeclarator), 0, (GInstanceInitFunc) vala_ccode_function_declarator_instance_init, NULL };
 		vala_ccode_function_declarator_type_id = g_type_register_static (VALA_TYPE_CCODE_DECLARATOR, "ValaCCodeFunctionDeclarator", &g_define_type_info, 0);
 	}
 	return vala_ccode_function_declarator_type_id;
