@@ -22,6 +22,8 @@
  */
 
 #include <gobject/valainterfaceregisterfunction.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <vala/valadatatype.h>
 #include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodeidentifier.h>
@@ -58,9 +60,9 @@ ValaInterfaceRegisterFunction* vala_interface_register_function_construct (GType
 	ValaInterfaceRegisterFunction* self;
 	g_return_val_if_fail (iface != NULL, NULL);
 	g_return_val_if_fail (context != NULL, NULL);
-	self = ((ValaInterfaceRegisterFunction*) (g_type_create_instance (object_type)));
+	self = (ValaInterfaceRegisterFunction*) g_type_create_instance (object_type);
 	vala_interface_register_function_set_interface_reference (self, iface);
-	vala_typeregister_function_set_context (((ValaTypeRegisterFunction*) (self)), context);
+	vala_typeregister_function_set_context ((ValaTypeRegisterFunction*) self, context);
 	return self;
 }
 
@@ -73,15 +75,15 @@ ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterfa
 static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
 	ValaTypeSymbol* _tmp0;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	_tmp0 = NULL;
-	return (_tmp0 = ((ValaTypeSymbol*) (self->priv->_interface_reference)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
+	return (_tmp0 = (ValaTypeSymbol*) self->priv->_interface_reference, (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
 }
 
 
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	return vala_interface_get_type_cname (self->priv->_interface_reference);
 }
 
@@ -90,99 +92,103 @@ static char* vala_interface_register_function_real_get_base_init_func_name (Vala
 	ValaInterfaceRegisterFunction * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_base_init", (_tmp0 = vala_symbol_get_lower_case_cname (((ValaSymbol*) (self->priv->_interface_reference)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%s_base_init", _tmp0 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_interface_reference, NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	return g_strdup ("NULL");
 }
 
 
 static char* vala_interface_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	return g_strdup ("0");
 }
 
 
 static char* vala_interface_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	return g_strdup ("NULL");
 }
 
 
 static char* vala_interface_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	return g_strdup ("G_TYPE_INTERFACE");
 }
 
 
 static ValaSymbolAccessibility vala_interface_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	self = ((ValaInterfaceRegisterFunction*) (base));
-	return vala_symbol_get_access (((ValaSymbol*) (self->priv->_interface_reference)));
+	self = (ValaInterfaceRegisterFunction*) base;
+	return vala_symbol_get_access ((ValaSymbol*) self->priv->_interface_reference);
 }
 
 
 static ValaCCodeFragment* vala_interface_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
 	ValaCCodeFragment* frag;
-	self = ((ValaInterfaceRegisterFunction*) (base));
+	self = (ValaInterfaceRegisterFunction*) base;
 	frag = vala_ccode_fragment_new ();
 	/* register all prerequisites */
 	{
-		GeeList* prereq_ref_collection;
-		int prereq_ref_it;
-		prereq_ref_collection = vala_interface_get_prerequisites (self->priv->_interface_reference);
-		for (prereq_ref_it = 0; prereq_ref_it < gee_collection_get_size (GEE_COLLECTION (prereq_ref_collection)); prereq_ref_it = prereq_ref_it + 1) {
+		GeeList* _tmp0;
+		GeeIterator* _tmp1;
+		GeeIterator* prereq_ref_it;
+		/* register all prerequisites */
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		prereq_ref_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_interface_get_prerequisites (self->priv->_interface_reference))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		/* register all prerequisites */
+		while (gee_iterator_next (prereq_ref_it)) {
 			ValaDataType* prereq_ref;
-			prereq_ref = ((ValaDataType*) (gee_list_get (GEE_LIST (prereq_ref_collection), prereq_ref_it)));
-			{
-				ValaTypeSymbol* _tmp0;
-				ValaTypeSymbol* prereq;
-				ValaCCodeIdentifier* _tmp1;
-				ValaCCodeFunctionCall* _tmp2;
-				ValaCCodeFunctionCall* func;
-				ValaCCodeIdentifier* _tmp5;
-				char* _tmp4;
-				char* _tmp3;
-				ValaCCodeIdentifier* _tmp7;
-				char* _tmp6;
-				ValaCCodeExpressionStatement* _tmp8;
-				_tmp0 = NULL;
-				prereq = (_tmp0 = vala_data_type_get_data_type (prereq_ref), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
-				_tmp1 = NULL;
-				_tmp2 = NULL;
-				func = (_tmp2 = vala_ccode_function_call_new (((ValaCCodeExpression*) ((_tmp1 = vala_ccode_identifier_new ("g_type_interface_add_prerequisite"))))), (_tmp1 == NULL ? NULL : (_tmp1 = (vala_ccode_node_unref (_tmp1), NULL))), _tmp2);
-				_tmp5 = NULL;
-				_tmp4 = NULL;
-				_tmp3 = NULL;
-				vala_ccode_function_call_add_argument (func, ((ValaCCodeExpression*) ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = g_strdup_printf ("%s_type_id", (_tmp3 = vala_symbol_get_lower_case_cname (((ValaSymbol*) (self->priv->_interface_reference)), NULL)))))))));
-				(_tmp5 == NULL ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)));
-				_tmp4 = (g_free (_tmp4), NULL);
-				_tmp3 = (g_free (_tmp3), NULL);
-				_tmp7 = NULL;
-				_tmp6 = NULL;
-				vala_ccode_function_call_add_argument (func, ((ValaCCodeExpression*) ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_type_id (prereq)))))));
-				(_tmp7 == NULL ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)));
-				_tmp6 = (g_free (_tmp6), NULL);
-				_tmp8 = NULL;
-				vala_ccode_fragment_append (frag, ((ValaCCodeNode*) ((_tmp8 = vala_ccode_expression_statement_new (((ValaCCodeExpression*) (func)))))));
-				(_tmp8 == NULL ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL)));
-				(prereq_ref == NULL ? NULL : (prereq_ref = (vala_code_node_unref (prereq_ref), NULL)));
-				(prereq == NULL ? NULL : (prereq = (vala_code_node_unref (prereq), NULL)));
-				(func == NULL ? NULL : (func = (vala_ccode_node_unref (func), NULL)));
-			}
+			ValaTypeSymbol* _tmp2;
+			ValaTypeSymbol* prereq;
+			ValaCCodeIdentifier* _tmp3;
+			ValaCCodeFunctionCall* _tmp4;
+			ValaCCodeFunctionCall* func;
+			ValaCCodeIdentifier* _tmp7;
+			char* _tmp6;
+			char* _tmp5;
+			ValaCCodeIdentifier* _tmp9;
+			char* _tmp8;
+			ValaCCodeExpressionStatement* _tmp10;
+			/* register all prerequisites */
+			prereq_ref = (ValaDataType*) gee_iterator_get (prereq_ref_it);
+			_tmp2 = NULL;
+			prereq = (_tmp2 = vala_data_type_get_data_type (prereq_ref), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
+			_tmp3 = NULL;
+			_tmp4 = NULL;
+			func = (_tmp4 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp3 = vala_ccode_identifier_new ("g_type_interface_add_prerequisite"))), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_ccode_node_unref (_tmp3), NULL)), _tmp4);
+			_tmp7 = NULL;
+			_tmp6 = NULL;
+			_tmp5 = NULL;
+			vala_ccode_function_call_add_argument (func, (ValaCCodeExpression*) (_tmp7 = vala_ccode_identifier_new (_tmp6 = g_strdup_printf ("%s_type_id", _tmp5 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_interface_reference, NULL)))));
+			(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL));
+			_tmp6 = (g_free (_tmp6), NULL);
+			_tmp5 = (g_free (_tmp5), NULL);
+			_tmp9 = NULL;
+			_tmp8 = NULL;
+			vala_ccode_function_call_add_argument (func, (ValaCCodeExpression*) (_tmp9 = vala_ccode_identifier_new (_tmp8 = vala_typesymbol_get_type_id (prereq))));
+			(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
+			_tmp8 = (g_free (_tmp8), NULL);
+			_tmp10 = NULL;
+			vala_ccode_fragment_append (frag, (ValaCCodeNode*) (_tmp10 = vala_ccode_expression_statement_new ((ValaCCodeExpression*) func)));
+			(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
+			(prereq_ref == NULL) ? NULL : (prereq_ref = (vala_code_node_unref (prereq_ref), NULL));
+			(prereq == NULL) ? NULL : (prereq = (vala_code_node_unref (prereq), NULL));
+			(func == NULL) ? NULL : (func = (vala_ccode_node_unref (func), NULL));
 		}
-		(prereq_ref_collection == NULL ? NULL : (prereq_ref_collection = (gee_collection_object_unref (prereq_ref_collection), NULL)));
+		(prereq_ref_it == NULL) ? NULL : (prereq_ref_it = (gee_collection_object_unref (prereq_ref_it), NULL));
 	}
 	return frag;
 }
