@@ -25,13 +25,11 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/list.h>
 #include <vala/valaobjecttypesymbol.h>
 #include <vala/valacodenode.h>
-#include <vala/valatypesymbol.h>
-#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -66,8 +64,6 @@ ValaClass* vala_class_construct (GType object_type, const char* name, ValaSource
 ValaClass* vala_class_new (const char* name, ValaSourceReference* source_reference);
 void vala_class_add_base_type (ValaClass* self, ValaDataType* type);
 GeeList* vala_class_get_base_types (ValaClass* self);
-void vala_class_add_type_parameter (ValaClass* self, ValaTypeParameter* p);
-GeeList* vala_class_get_type_parameters (ValaClass* self);
 void vala_class_add_constant (ValaClass* self, ValaConstant* c);
 void vala_class_add_field (ValaClass* self, ValaField* f);
 GeeList* vala_class_get_fields (ValaClass* self);
@@ -94,8 +90,6 @@ ValaClass* vala_class_get_base_class (ValaClass* self);
 void vala_class_set_base_class (ValaClass* self, ValaClass* value);
 gboolean vala_class_get_is_abstract (ValaClass* self);
 void vala_class_set_is_abstract (ValaClass* self, gboolean value);
-gboolean vala_class_get_is_static (ValaClass* self);
-void vala_class_set_is_static (ValaClass* self, gboolean value);
 gboolean vala_class_get_is_compact (ValaClass* self);
 void vala_class_set_is_compact (ValaClass* self, gboolean value);
 gboolean vala_class_get_is_immutable (ValaClass* self);
@@ -114,7 +108,6 @@ void vala_class_set_static_constructor (ValaClass* self, ValaConstructor* value)
 ValaDestructor* vala_class_get_destructor (ValaClass* self);
 void vala_class_set_destructor (ValaClass* self, ValaDestructor* value);
 gboolean vala_class_get_is_error_base (ValaClass* self);
-void vala_class_set_is_error_base (ValaClass* self, gboolean value);
 GType vala_class_get_type (void);
 
 
