@@ -22,16 +22,17 @@
  */
 
 #include <vala/valaformalparameter.h>
+#include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valaexpression.h>
 #include <vala/valaattribute.h>
 #include <vala/valasemanticanalyzer.h>
 #include <vala/valasourcefile.h>
+#include <vala/valaarraytype.h>
+#include <vala/valareport.h>
 #include <vala/valacodecontext.h>
 #include <vala/valanullliteral.h>
-#include <vala/valareport.h>
 #include <vala/valavaluetype.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valamethod.h>
@@ -47,6 +48,7 @@
 struct _ValaFormalParameterPrivate {
 	ValaParameterDirection _direction;
 	gboolean _ellipsis;
+	gboolean _params_array;
 	ValaExpression* _default_expression;
 	gboolean _no_array_length;
 	gboolean _construct_parameter;
@@ -84,10 +86,9 @@ ValaFormalParameter* vala_formal_parameter_construct (GType object_type, const c
 	ValaFormalParameter* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (parameter_type != NULL, NULL);
-	self = ((ValaFormalParameter*) (g_type_create_instance (object_type)));
-	self = ((ValaFormalParameter*) (vala_symbol_construct (object_type, name, source_reference)));
+	self = (ValaFormalParameter*) vala_symbol_construct (object_type, name, source_reference);
 	vala_formal_parameter_set_parameter_type (self, parameter_type);
-	vala_symbol_set_access (((ValaSymbol*) (self)), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	vala_symbol_set_access ((ValaSymbol*) self, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	return self;
 }
 
@@ -103,10 +104,9 @@ ValaFormalParameter* vala_formal_parameter_new (const char* name, ValaDataType*
  */
 ValaFormalParameter* vala_formal_parameter_construct_with_ellipsis (GType object_type, ValaSourceReference* source_reference) {
 	ValaFormalParameter* self;
-	self = ((ValaFormalParameter*) (g_type_create_instance (object_type)));
-	self = ((ValaFormalParameter*) (vala_symbol_construct (object_type, NULL, source_reference)));
+	self = (ValaFormalParameter*) vala_symbol_construct (object_type, NULL, source_reference);
 	vala_formal_parameter_set_ellipsis (self, TRUE);
-	vala_symbol_set_access (((ValaSymbol*) (self)), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	vala_symbol_set_access ((ValaSymbol*) self, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	return self;
 }
 
@@ -118,7 +118,7 @@ ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReferenc
 
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
-	self = ((ValaFormalParameter*) (base));
+	self = (ValaFormalParameter*) base;
 	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_formal_parameter (visitor, self);
 }
@@ -126,12 +126,12 @@ static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisit
 
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
-	self = ((ValaFormalParameter*) (base));
+	self = (ValaFormalParameter*) base;
 	g_return_if_fail (visitor != NULL);
 	if (!self->priv->_ellipsis) {
-		vala_code_node_accept (((ValaCodeNode*) (vala_formal_parameter_get_parameter_type (self))), visitor);
+		vala_code_node_accept ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self), visitor);
 		if (self->priv->_default_expression != NULL) {
-			vala_code_node_accept (((ValaCodeNode*) (self->priv->_default_expression)), visitor);
+			vala_code_node_accept ((ValaCodeNode*) self->priv->_default_expression, visitor);
 		}
 	}
 }
@@ -139,7 +139,7 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 
 static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaFormalParameter * self;
-	self = ((ValaFormalParameter*) (base));
+	self = (ValaFormalParameter*) base;
 	g_return_if_fail (old_type != NULL);
 	g_return_if_fail (new_type != NULL);
 	if (vala_formal_parameter_get_parameter_type (self) == old_type) {
@@ -154,7 +154,7 @@ static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter*
 	if (vala_attribute_has_argument (a, "type")) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		vala_formal_parameter_set_ctype (self, (_tmp0 = vala_attribute_get_string (a, "type")));
+		vala_formal_parameter_set_ctype (self, _tmp0 = vala_attribute_get_string (a, "type"));
 		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	if (vala_attribute_has_argument (a, "array_length_pos")) {
@@ -174,17 +174,17 @@ void vala_formal_parameter_process_attributes (ValaFormalParameter* self) {
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) (self))->attributes;
+		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
+			a = (_tmp0 = (ValaAttribute*) a_it->data, (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_formal_parameter_process_ccode_attribute (self, a);
 				}
-				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
+				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
 			}
 		}
 	}
@@ -195,7 +195,8 @@ ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	if (!self->priv->_ellipsis) {
 		ValaFormalParameter* result;
-		result = vala_formal_parameter_new (vala_symbol_get_name (((ValaSymbol*) (self))), vala_formal_parameter_get_parameter_type (self), vala_code_node_get_source_reference (((ValaCodeNode*) (self))));
+		result = vala_formal_parameter_new (vala_symbol_get_name ((ValaSymbol*) self), vala_formal_parameter_get_parameter_type (self), vala_code_node_get_source_reference ((ValaCodeNode*) self));
+		vala_formal_parameter_set_params_array (result, self->priv->_params_array);
 		return result;
 	} else {
 		return vala_formal_parameter_new_with_ellipsis (NULL);
@@ -209,36 +210,86 @@ static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemant
 	ValaSourceFile* old_source_file;
 	ValaSymbol* _tmp2;
 	ValaSymbol* old_symbol;
-	gboolean _tmp13;
-	self = ((ValaFormalParameter*) (base));
+	gboolean _tmp5;
+	gboolean _tmp19;
+	self = (ValaFormalParameter*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	if (vala_code_node_get_checked (((ValaCodeNode*) (self)))) {
-		return !vala_code_node_get_error (((ValaCodeNode*) (self)));
+	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
+		return !vala_code_node_get_error ((ValaCodeNode*) self);
 	}
-	vala_code_node_set_checked (((ValaCodeNode*) (self)), TRUE);
+	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	vala_formal_parameter_process_attributes (self);
 	_tmp1 = NULL;
-	old_source_file = (_tmp1 = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp1 == NULL ? NULL : vala_source_file_ref (_tmp1)));
+	old_source_file = (_tmp1 = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp1 == NULL) ? NULL : vala_source_file_ref (_tmp1));
 	_tmp2 = NULL;
-	old_symbol = (_tmp2 = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2)));
-	if (vala_code_node_get_source_reference (((ValaCodeNode*) (self))) != NULL) {
-		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) (self)))));
+	old_symbol = (_tmp2 = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
+	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
+		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
-	vala_semantic_analyzer_set_current_symbol (analyzer, vala_symbol_get_parent_symbol (((ValaSymbol*) (self))));
-	vala_code_node_accept_children (((ValaCodeNode*) (self)), ((ValaCodeVisitor*) (analyzer)));
-	if (vala_code_context_get_non_null (vala_semantic_analyzer_get_context (analyzer)) && self->priv->_default_expression != NULL) {
-		if (VALA_IS_NULL_LITERAL (self->priv->_default_expression) && !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (self)) && self->priv->_direction != VALA_PARAMETER_DIRECTION_OUT) {
-			char* _tmp4;
-			char* _tmp3;
-			_tmp4 = NULL;
-			_tmp3 = NULL;
-			vala_report_warning (vala_code_node_get_source_reference (((ValaCodeNode*) (self))), (_tmp4 = g_strdup_printf ("`null' incompatible with parameter type `%s`", (_tmp3 = vala_code_node_to_string (((ValaCodeNode*) (vala_formal_parameter_get_parameter_type (self))))))));
-			_tmp4 = (g_free (_tmp4), NULL);
-			_tmp3 = (g_free (_tmp3), NULL);
+	vala_semantic_analyzer_set_current_symbol (analyzer, vala_symbol_get_parent_symbol ((ValaSymbol*) self));
+	if (vala_formal_parameter_get_parameter_type (self) != NULL) {
+		vala_code_node_check ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self), analyzer);
+	}
+	if (!self->priv->_ellipsis) {
+		gboolean _tmp3;
+		vala_code_node_check ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self), analyzer);
+		_tmp3 = FALSE;
+		if (self->priv->_params_array) {
+			_tmp3 = !(VALA_IS_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (self)));
+		} else {
+			_tmp3 = FALSE;
+		}
+		if (_tmp3) {
+			gboolean _tmp4;
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "parameter array expected");
+			return (_tmp4 = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp4);
+		}
+		if (self->priv->_default_expression != NULL) {
+			vala_code_node_check ((ValaCodeNode*) self->priv->_default_expression, analyzer);
+		}
+	}
+	_tmp5 = FALSE;
+	if (vala_code_context_get_non_null (vala_semantic_analyzer_get_context (analyzer))) {
+		_tmp5 = self->priv->_default_expression != NULL;
+	} else {
+		_tmp5 = FALSE;
+	}
+	if (_tmp5) {
+		gboolean _tmp6;
+		gboolean _tmp7;
+		_tmp6 = FALSE;
+		_tmp7 = FALSE;
+		if (VALA_IS_NULL_LITERAL (self->priv->_default_expression)) {
+			_tmp7 = !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (self));
+		} else {
+			_tmp7 = FALSE;
+		}
+		if (_tmp7) {
+			_tmp6 = self->priv->_direction != VALA_PARAMETER_DIRECTION_OUT;
+		} else {
+			_tmp6 = FALSE;
+		}
+		if (_tmp6) {
+			char* _tmp9;
+			char* _tmp8;
+			_tmp9 = NULL;
+			_tmp8 = NULL;
+			vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9 = g_strdup_printf ("`null' incompatible with parameter type `%s`", _tmp8 = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self))));
+			_tmp9 = (g_free (_tmp9), NULL);
+			_tmp8 = (g_free (_tmp8), NULL);
 		}
 	}
 	if (!self->priv->_ellipsis) {
-		if (!vala_symbol_is_internal_symbol (((ValaSymbol*) (self)))) {
-			if (VALA_IS_VALUE_TYPE (vala_formal_parameter_get_parameter_type (self)) && !vala_data_type_is_real_struct_type (vala_formal_parameter_get_parameter_type (self))) {
+		if (!vala_symbol_is_internal_symbol ((ValaSymbol*) self)) {
+			gboolean _tmp10;
+			_tmp10 = FALSE;
+			if (VALA_IS_VALUE_TYPE (vala_formal_parameter_get_parameter_type (self))) {
+				_tmp10 = !vala_data_type_is_real_struct_type (vala_formal_parameter_get_parameter_type (self));
+			} else {
+				_tmp10 = FALSE;
+			}
+			if (_tmp10) {
 				vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_formal_parameter_get_parameter_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_FULL);
 			} else {
 				vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_formal_parameter_get_parameter_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_SHALLOW);
@@ -246,52 +297,52 @@ static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemant
 		}
 		vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_formal_parameter_get_parameter_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE);
 		/* check whether parameter type is at least as accessible as the method*/
-		if (!vala_semantic_analyzer_is_type_accessible (analyzer, ((ValaSymbol*) (self)), vala_formal_parameter_get_parameter_type (self))) {
-			char* _tmp7;
-			char* _tmp6;
-			char* _tmp5;
-			vala_code_node_set_error (((ValaCodeNode*) (self)), TRUE);
-			_tmp7 = NULL;
-			_tmp6 = NULL;
-			_tmp5 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) (self))), (_tmp7 = g_strdup_printf ("parameter type `%s` is less accessible than method `%s`", (_tmp5 = vala_code_node_to_string (((ValaCodeNode*) (vala_formal_parameter_get_parameter_type (self))))), (_tmp6 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (((ValaSymbol*) (self))))))));
-			_tmp7 = (g_free (_tmp7), NULL);
-			_tmp6 = (g_free (_tmp6), NULL);
-			_tmp5 = (g_free (_tmp5), NULL);
+		if (!vala_semantic_analyzer_is_type_accessible (analyzer, (ValaSymbol*) self, vala_formal_parameter_get_parameter_type (self))) {
+			char* _tmp13;
+			char* _tmp12;
+			char* _tmp11;
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			_tmp13 = NULL;
+			_tmp12 = NULL;
+			_tmp11 = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp13 = g_strdup_printf ("parameter type `%s` is less accessible than method `%s`", _tmp11 = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self)), _tmp12 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))));
+			_tmp13 = (g_free (_tmp13), NULL);
+			_tmp12 = (g_free (_tmp12), NULL);
+			_tmp11 = (g_free (_tmp11), NULL);
 		}
 	}
 	/* special treatment for construct formal parameters used in creation methods */
 	if (self->priv->_construct_parameter) {
-		ValaBlock* _tmp8;
+		ValaBlock* _tmp14;
 		ValaBlock* method_body;
-		ValaMemberAccess* _tmp9;
-		ValaMemberAccess* _tmp10;
+		ValaMemberAccess* _tmp15;
+		ValaMemberAccess* _tmp16;
 		ValaMemberAccess* left;
 		ValaMemberAccess* right;
-		ValaExpressionStatement* _tmp12;
-		ValaAssignment* _tmp11;
-		if (!(VALA_IS_CREATION_METHOD (vala_symbol_get_parent_symbol (((ValaSymbol*) (self)))))) {
-			vala_code_node_set_error (((ValaCodeNode*) (self)), TRUE);
-			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) (self))), "construct parameters are only allowed in type creation methods");
+		ValaExpressionStatement* _tmp18;
+		ValaAssignment* _tmp17;
+		if (!(VALA_IS_CREATION_METHOD (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))) {
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "construct parameters are only allowed in type creation methods");
 		}
-		_tmp8 = NULL;
-		method_body = (_tmp8 = vala_method_get_body (((ValaMethod*) ((VALA_CREATION_METHOD (vala_symbol_get_parent_symbol (((ValaSymbol*) (self)))))))), (_tmp8 == NULL ? NULL : vala_code_node_ref (_tmp8)));
-		_tmp9 = NULL;
-		_tmp10 = NULL;
-		left = (_tmp10 = vala_member_access_new (((ValaExpression*) ((_tmp9 = vala_member_access_new_simple ("this", NULL)))), vala_symbol_get_name (((ValaSymbol*) (self))), NULL), (_tmp9 == NULL ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL))), _tmp10);
-		right = vala_member_access_new_simple (vala_symbol_get_name (((ValaSymbol*) (self))), NULL);
-		_tmp12 = NULL;
-		_tmp11 = NULL;
-		vala_block_add_statement (method_body, ((ValaStatement*) ((_tmp12 = vala_expression_statement_new (((ValaExpression*) ((_tmp11 = vala_assignment_new (((ValaExpression*) (left)), ((ValaExpression*) (right)), VALA_ASSIGNMENT_OPERATOR_SIMPLE, NULL)))), vala_code_node_get_source_reference (((ValaCodeNode*) (self))))))));
-		(_tmp12 == NULL ? NULL : (_tmp12 = (vala_code_node_unref (_tmp12), NULL)));
-		(_tmp11 == NULL ? NULL : (_tmp11 = (vala_code_node_unref (_tmp11), NULL)));
-		(method_body == NULL ? NULL : (method_body = (vala_code_node_unref (method_body), NULL)));
-		(left == NULL ? NULL : (left = (vala_code_node_unref (left), NULL)));
-		(right == NULL ? NULL : (right = (vala_code_node_unref (right), NULL)));
+		_tmp14 = NULL;
+		method_body = (_tmp14 = vala_method_get_body ((ValaMethod*) (VALA_CREATION_METHOD (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), (_tmp14 == NULL) ? NULL : vala_code_node_ref (_tmp14));
+		_tmp15 = NULL;
+		_tmp16 = NULL;
+		left = (_tmp16 = vala_member_access_new ((ValaExpression*) (_tmp15 = vala_member_access_new_simple ("this", NULL)), vala_symbol_get_name ((ValaSymbol*) self), NULL), (_tmp15 == NULL) ? NULL : (_tmp15 = (vala_code_node_unref (_tmp15), NULL)), _tmp16);
+		right = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) self), NULL);
+		_tmp18 = NULL;
+		_tmp17 = NULL;
+		vala_block_add_statement (method_body, (ValaStatement*) (_tmp18 = vala_expression_statement_new ((ValaExpression*) (_tmp17 = vala_assignment_new ((ValaExpression*) left, (ValaExpression*) right, VALA_ASSIGNMENT_OPERATOR_SIMPLE, NULL)), vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+		(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_code_node_unref (_tmp18), NULL));
+		(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_code_node_unref (_tmp17), NULL));
+		(method_body == NULL) ? NULL : (method_body = (vala_code_node_unref (method_body), NULL));
+		(left == NULL) ? NULL : (left = (vala_code_node_unref (left), NULL));
+		(right == NULL) ? NULL : (right = (vala_code_node_unref (right), NULL));
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	return (_tmp13 = !vala_code_node_get_error (((ValaCodeNode*) (self))), (old_source_file == NULL ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL))), (old_symbol == NULL ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL))), _tmp13);
+	return (_tmp19 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp19);
 }
 
 
@@ -307,8 +358,8 @@ void vala_formal_parameter_set_parameter_type (ValaFormalParameter* self, ValaDa
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
-	vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_data_type)), ((ValaCodeNode*) (self)));
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
 
@@ -336,6 +387,18 @@ void vala_formal_parameter_set_ellipsis (ValaFormalParameter* self, gboolean val
 }
 
 
+gboolean vala_formal_parameter_get_params_array (ValaFormalParameter* self) {
+	g_return_val_if_fail (self != NULL, FALSE);
+	return self->priv->_params_array;
+}
+
+
+void vala_formal_parameter_set_params_array (ValaFormalParameter* self, gboolean value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_params_array = value;
+}
+
+
 ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParameter* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_default_expression;
@@ -348,7 +411,7 @@ void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, Va
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL))), _tmp2);
+	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_default_expression == NULL) ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL)), _tmp2);
 }
 
 
@@ -424,7 +487,7 @@ void vala_formal_parameter_set_ctype (ValaFormalParameter* self, const char* val
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_ctype = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_ctype = (g_free (self->priv->_ctype), NULL)), _tmp2);
+	self->priv->_ctype = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_ctype = (g_free (self->priv->_ctype), NULL), _tmp2);
 }
 
 
@@ -448,9 +511,9 @@ static void vala_formal_parameter_instance_init (ValaFormalParameter * self) {
 static void vala_formal_parameter_finalize (ValaCodeNode* obj) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (obj);
-	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL)));
+	(self->priv->_default_expression == NULL) ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL));
 	self->priv->_ctype = (g_free (self->priv->_ctype), NULL);
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	(self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL));
 	VALA_CODE_NODE_CLASS (vala_formal_parameter_parent_class)->finalize (obj);
 }
 
@@ -481,7 +544,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2) {
 		return -(str1 != str2);
 	}
 	if (str2 == NULL) {
-		return (str1 != str2);
+		return str1 != str2;
 	}
 	return strcmp (str1, str2);
 }
