@@ -21,6 +21,8 @@
  */
 
 #include <vala/valainterfacetype.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <vala/valacodenode.h>
 
 
@@ -44,7 +46,7 @@ static void vala_interface_type_finalize (ValaCodeNode* obj);
 ValaInterfaceType* vala_interface_type_construct (GType object_type, ValaInterface* interface_symbol) {
 	ValaInterfaceType* self;
 	g_return_val_if_fail (interface_symbol != NULL, NULL);
-	self = ((ValaInterfaceType*) (g_type_create_instance (object_type)));
+	self = (ValaInterfaceType*) g_type_create_instance (object_type);
 	vala_interface_type_set_interface_symbol (self, interface_symbol);
 	return self;
 }
@@ -58,31 +60,32 @@ ValaInterfaceType* vala_interface_type_new (ValaInterface* interface_symbol) {
 static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 	ValaInterfaceType * self;
 	ValaInterfaceType* result;
-	self = ((ValaInterfaceType*) (base));
+	self = (ValaInterfaceType*) base;
 	result = vala_interface_type_new (self->priv->_interface_symbol);
-	vala_code_node_set_source_reference (((ValaCodeNode*) (result)), vala_code_node_get_source_reference (((ValaCodeNode*) (self))));
-	vala_data_type_set_value_owned (((ValaDataType*) (result)), vala_data_type_get_value_owned (((ValaDataType*) (self))));
-	vala_data_type_set_nullable (((ValaDataType*) (result)), vala_data_type_get_nullable (((ValaDataType*) (self))));
-	vala_data_type_set_is_dynamic (((ValaDataType*) (result)), vala_data_type_get_is_dynamic (((ValaDataType*) (self))));
-	vala_data_type_set_floating_reference (((ValaDataType*) (result)), vala_data_type_get_floating_reference (((ValaDataType*) (self))));
+	vala_code_node_set_source_reference ((ValaCodeNode*) result, vala_code_node_get_source_reference ((ValaCodeNode*) self));
+	vala_data_type_set_value_owned ((ValaDataType*) result, vala_data_type_get_value_owned ((ValaDataType*) self));
+	vala_data_type_set_nullable ((ValaDataType*) result, vala_data_type_get_nullable ((ValaDataType*) self));
+	vala_data_type_set_is_dynamic ((ValaDataType*) result, vala_data_type_get_is_dynamic ((ValaDataType*) self));
+	vala_data_type_set_floating_reference ((ValaDataType*) result, vala_data_type_get_floating_reference ((ValaDataType*) self));
 	{
-		GeeList* arg_collection;
-		int arg_it;
-		arg_collection = vala_data_type_get_type_arguments (((ValaDataType*) (self)));
-		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
+		GeeList* _tmp0;
+		GeeIterator* _tmp1;
+		GeeIterator* arg_it;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		arg_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (arg_it)) {
 			ValaDataType* arg;
-			arg = ((ValaDataType*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
-			{
-				ValaDataType* _tmp0;
-				_tmp0 = NULL;
-				vala_data_type_add_type_argument (((ValaDataType*) (result)), (_tmp0 = vala_data_type_copy (arg)));
-				(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
-				(arg == NULL ? NULL : (arg = (vala_code_node_unref (arg), NULL)));
-			}
+			ValaDataType* _tmp2;
+			arg = (ValaDataType*) gee_iterator_get (arg_it);
+			_tmp2 = NULL;
+			vala_data_type_add_type_argument ((ValaDataType*) result, _tmp2 = vala_data_type_copy (arg));
+			(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
-		(arg_collection == NULL ? NULL : (arg_collection = (gee_collection_object_unref (arg_collection), NULL)));
+		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
 	}
-	return ((ValaDataType*) (result));
+	return (ValaDataType*) result;
 }
 
 
@@ -90,10 +93,10 @@ static char* vala_interface_type_real_get_cname (ValaDataType* base) {
 	ValaInterfaceType * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaInterfaceType*) (base));
+	self = (ValaInterfaceType*) base;
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%sIface*", (_tmp0 = vala_typesymbol_get_cname (((ValaTypeSymbol*) (self->priv->_interface_symbol)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%sIface*", _tmp0 = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_interface_symbol, FALSE)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
