@@ -23,9 +23,11 @@
 #include <vala/valamember.h>
 #include <gee/arraylist.h>
 #include <gee/collection.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <gee/readonlylist.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valasourcereference.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valasourcefile.h>
 
 
@@ -42,46 +44,83 @@ enum  {
 static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base);
 static gpointer vala_member_parent_class = NULL;
-static void vala_member_finalize (GObject * obj);
+static void vala_member_finalize (ValaCodeNode* obj);
 
 
 
+ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+	ValaMember* self;
+	self = (ValaMember*) vala_symbol_construct (object_type, name, source_reference);
+	return self;
+}
+
+
+ValaMember* vala_member_new (const char* name, ValaSourceReference* source_reference) {
+	return vala_member_construct (VALA_TYPE_MEMBER, name, source_reference);
+}
+
+
 static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMember * self;
-	self = VALA_MEMBER (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = (ValaMember*) base;
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_member (visitor, self);
 }
 
 
 static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaMember * self;
-	self = VALA_MEMBER (base);
-	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) != NULL) {
+	gboolean _tmp0;
+	self = (ValaMember*) base;
+	_tmp0 = FALSE;
+	if (gee_collection_get_size ((GeeCollection*) self->priv->cheader_filenames) == 0) {
+		_tmp0 = vala_symbol_get_parent_symbol ((ValaSymbol*) self) != NULL;
+	} else {
+		_tmp0 = FALSE;
+	}
+	if (_tmp0) {
+		gboolean _tmp3;
+		gboolean _tmp4;
 		/* default to header filenames of the namespace */
 		{
-			GeeList* filename_collection;
-			int filename_it;
-			filename_collection = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)));
-			for (filename_it = 0; filename_it < gee_collection_get_size (GEE_COLLECTION (filename_collection)); filename_it = filename_it + 1) {
+			GeeList* _tmp1;
+			GeeIterator* _tmp2;
+			GeeIterator* filename_it;
+			/* default to header filenames of the namespace */
+			_tmp1 = NULL;
+			_tmp2 = NULL;
+			filename_it = (_tmp2 = gee_iterable_iterator ((GeeIterable*) (_tmp1 = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), (_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)), _tmp2);
+			/* default to header filenames of the namespace */
+			while (gee_iterator_next (filename_it)) {
 				char* filename;
-				filename = ((char*) (gee_list_get (GEE_LIST (filename_collection), filename_it)));
-				{
-					vala_member_add_cheader_filename (self, filename);
-					filename = (g_free (filename), NULL);
-				}
+				/* default to header filenames of the namespace */
+				filename = (char*) gee_iterator_get (filename_it);
+				vala_member_add_cheader_filename (self, filename);
+				filename = (g_free (filename), NULL);
 			}
-			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
+			(filename_it == NULL) ? NULL : (filename_it = (gee_collection_object_unref (filename_it), NULL));
 		}
-		if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_symbol_get_external_package (VALA_SYMBOL (self))) {
-			char* _tmp0;
+		_tmp3 = FALSE;
+		_tmp4 = FALSE;
+		if (gee_collection_get_size ((GeeCollection*) self->priv->cheader_filenames) == 0) {
+			_tmp4 = vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL;
+		} else {
+			_tmp4 = FALSE;
+		}
+		if (_tmp4) {
+			_tmp3 = !vala_symbol_get_external_package ((ValaSymbol*) self);
+		} else {
+			_tmp3 = FALSE;
+		}
+		if (_tmp3) {
+			char* _tmp5;
 			/* don't add default include directives for VAPI files*/
-			_tmp0 = NULL;
-			gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), (_tmp0 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
-			_tmp0 = (g_free (_tmp0), NULL);
+			_tmp5 = NULL;
+			gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, _tmp5 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+			_tmp5 = (g_free (_tmp5), NULL);
 		}
 	}
-	return GEE_LIST (gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->cheader_filenames));
+	return (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->cheader_filenames);
 }
 
 
@@ -92,26 +131,16 @@ static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
  * @param filename a C header filename
  */
 void vala_member_add_cheader_filename (ValaMember* self, const char* filename) {
-	g_return_if_fail (VALA_IS_MEMBER (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (filename != NULL);
-	gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
-}
-
-
-/**
- * Represents a general class member.
- */
-ValaMember* vala_member_new (void) {
-	ValaMember * self;
-	self = g_object_newv (VALA_TYPE_MEMBER, 0, NULL);
-	return self;
+	gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, filename);
 }
 
 
 static void vala_member_class_init (ValaMemberClass * klass) {
 	vala_member_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_member_finalize;
 	g_type_class_add_private (klass, sizeof (ValaMemberPrivate));
-	G_OBJECT_CLASS (klass)->finalize = vala_member_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_real_accept;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_member_real_get_cheader_filenames;
 }
@@ -119,23 +148,23 @@ static void vala_member_class_init (ValaMemberClass * klass) {
 
 static void vala_member_instance_init (ValaMember * self) {
 	self->priv = VALA_MEMBER_GET_PRIVATE (self);
-	self->priv->cheader_filenames = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal));
+	self->priv->cheader_filenames = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal);
 }
 
 
-static void vala_member_finalize (GObject * obj) {
+static void vala_member_finalize (ValaCodeNode* obj) {
 	ValaMember * self;
 	self = VALA_MEMBER (obj);
-	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
-	G_OBJECT_CLASS (vala_member_parent_class)->finalize (obj);
+	(self->priv->cheader_filenames == NULL) ? NULL : (self->priv->cheader_filenames = (gee_collection_object_unref (self->priv->cheader_filenames), NULL));
+	VALA_CODE_NODE_CLASS (vala_member_parent_class)->finalize (obj);
 }
 
 
 GType vala_member_get_type (void) {
 	static GType vala_member_type_id = 0;
 	if (vala_member_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMember), 0, (GInstanceInitFunc) vala_member_instance_init };
-		vala_member_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaMember", &g_define_type_info, 0);
+		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMember), 0, (GInstanceInitFunc) vala_member_instance_init, NULL };
+		vala_member_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaMember", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_member_type_id;
 }
