@@ -23,6 +23,8 @@
 
 #include <vala/valaunresolvedtype.h>
 #include <gee/list.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <vala/valacodenode.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valareport.h>
@@ -47,7 +49,7 @@ static void vala_unresolved_type_finalize (ValaCodeNode* obj);
 
 ValaUnresolvedType* vala_unresolved_type_construct (GType object_type) {
 	ValaUnresolvedType* self;
-	self = ((ValaUnresolvedType*) (g_type_create_instance (object_type)));
+	self = (ValaUnresolvedType*) g_type_create_instance (object_type);
 	return self;
 }
 
@@ -66,11 +68,10 @@ ValaUnresolvedType* vala_unresolved_type_new (void) {
  */
 ValaUnresolvedType* vala_unresolved_type_construct_from_symbol (GType object_type, ValaUnresolvedSymbol* symbol, ValaSourceReference* source) {
 	ValaUnresolvedType* self;
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_SYMBOL (symbol), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = ((ValaUnresolvedType*) (g_type_create_instance (object_type)));
+	g_return_val_if_fail (symbol != NULL, NULL);
+	self = (ValaUnresolvedType*) g_type_create_instance (object_type);
 	vala_unresolved_type_set_unresolved_symbol (self, symbol);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
 
@@ -88,19 +89,14 @@ ValaUnresolvedType* vala_unresolved_type_new_from_symbol (ValaUnresolvedSymbol*
  * @return       newly created type reference
  */
 ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* expr) {
-	char* ns;
-	char* type_name;
-	ValaUnresolvedType* _tmp8;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
-	ns = NULL;
-	type_name = NULL;
+	g_return_val_if_fail (expr != NULL, NULL);
 	if (VALA_IS_MEMBER_ACCESS (expr)) {
 		ValaUnresolvedType* type_ref;
 		ValaMemberAccess* _tmp0;
 		ValaMemberAccess* ma;
 		type_ref = NULL;
 		_tmp0 = NULL;
-		ma = (_tmp0 = VALA_MEMBER_ACCESS (expr), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
+		ma = (_tmp0 = VALA_MEMBER_ACCESS (expr), (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
 		if (vala_member_access_get_inner (ma) != NULL) {
 			if (VALA_IS_MEMBER_ACCESS (vala_member_access_get_inner (ma))) {
 				ValaMemberAccess* _tmp1;
@@ -109,50 +105,47 @@ ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* ex
 				ValaUnresolvedSymbol* _tmp3;
 				ValaUnresolvedSymbol* _tmp2;
 				_tmp1 = NULL;
-				simple = (_tmp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
+				simple = (_tmp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
 				_tmp4 = NULL;
 				_tmp3 = NULL;
 				_tmp2 = NULL;
-				type_ref = (_tmp4 = vala_unresolved_type_new_from_symbol ((_tmp3 = vala_unresolved_symbol_new ((_tmp2 = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (simple), vala_code_node_get_source_reference (VALA_CODE_NODE (ma)))), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma)))), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL))), _tmp4);
-				(_tmp3 == NULL ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL)));
-				(_tmp2 == NULL ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL)));
-				(simple == NULL ? NULL : (simple = (vala_code_node_unref (simple), NULL)));
+				type_ref = (_tmp4 = vala_unresolved_type_new_from_symbol (_tmp3 = vala_unresolved_symbol_new (_tmp2 = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (simple), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), (type_ref == NULL) ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL)), _tmp4);
+				(_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL));
+				(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+				(simple == NULL) ? NULL : (simple = (vala_code_node_unref (simple), NULL));
 			}
 		} else {
 			ValaUnresolvedType* _tmp6;
 			ValaUnresolvedSymbol* _tmp5;
 			_tmp6 = NULL;
 			_tmp5 = NULL;
-			type_ref = (_tmp6 = vala_unresolved_type_new_from_symbol ((_tmp5 = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma)))), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL))), _tmp6);
-			(_tmp5 == NULL ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL)));
+			type_ref = (_tmp6 = vala_unresolved_type_new_from_symbol (_tmp5 = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), (type_ref == NULL) ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL)), _tmp6);
+			(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL));
 		}
 		if (type_ref != NULL) {
 			GeeList* type_args;
 			ValaUnresolvedType* _tmp7;
-			vala_data_type_set_value_owned (VALA_DATA_TYPE (type_ref), TRUE);
+			vala_data_type_set_value_owned ((ValaDataType*) type_ref, TRUE);
 			type_args = vala_member_access_get_type_arguments (ma);
 			{
-				GeeList* arg_collection;
-				int arg_it;
-				arg_collection = type_args;
-				for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
+				GeeIterator* arg_it;
+				arg_it = gee_iterable_iterator ((GeeIterable*) type_args);
+				while (gee_iterator_next (arg_it)) {
 					ValaDataType* arg;
-					arg = ((ValaDataType*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
-					{
-						vala_data_type_add_type_argument (VALA_DATA_TYPE (type_ref), arg);
-						(arg == NULL ? NULL : (arg = (vala_code_node_unref (arg), NULL)));
-					}
+					arg = (ValaDataType*) gee_iterator_get (arg_it);
+					vala_data_type_add_type_argument ((ValaDataType*) type_ref, arg);
+					(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 				}
+				(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
 			}
 			_tmp7 = NULL;
-			return (_tmp7 = type_ref, (type_args == NULL ? NULL : (type_args = (gee_collection_object_unref (type_args), NULL))), (ma == NULL ? NULL : (ma = (vala_code_node_unref (ma), NULL))), (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp7);
+			return (_tmp7 = type_ref, (type_args == NULL) ? NULL : (type_args = (gee_collection_object_unref (type_args), NULL)), (ma == NULL) ? NULL : (ma = (vala_code_node_unref (ma), NULL)), _tmp7);
 		}
-		(type_ref == NULL ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL)));
-		(ma == NULL ? NULL : (ma = (vala_code_node_unref (ma), NULL)));
+		(type_ref == NULL) ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL));
+		(ma == NULL) ? NULL : (ma = (vala_code_node_unref (ma), NULL));
 	}
-	vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (expr)), "Type reference must be simple name or member access expression");
-	_tmp8 = NULL;
-	return (_tmp8 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp8);
+	vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) expr), "Type reference must be simple name or member access expression");
+	return NULL;
 }
 
 
@@ -160,46 +153,46 @@ static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 	ValaUnresolvedType * self;
 	ValaUnresolvedType* result;
 	ValaUnresolvedSymbol* _tmp0;
-	self = VALA_UNRESOLVED_TYPE (base);
+	self = (ValaUnresolvedType*) base;
 	result = vala_unresolved_type_new ();
-	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-	vala_data_type_set_value_owned (VALA_DATA_TYPE (result), vala_data_type_get_value_owned (VALA_DATA_TYPE (self)));
-	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
-	vala_data_type_set_is_dynamic (VALA_DATA_TYPE (result), vala_data_type_get_is_dynamic (VALA_DATA_TYPE (self)));
+	vala_code_node_set_source_reference ((ValaCodeNode*) result, vala_code_node_get_source_reference ((ValaCodeNode*) self));
+	vala_data_type_set_value_owned ((ValaDataType*) result, vala_data_type_get_value_owned ((ValaDataType*) self));
+	vala_data_type_set_nullable ((ValaDataType*) result, vala_data_type_get_nullable ((ValaDataType*) self));
+	vala_data_type_set_is_dynamic ((ValaDataType*) result, vala_data_type_get_is_dynamic ((ValaDataType*) self));
 	_tmp0 = NULL;
-	vala_unresolved_type_set_unresolved_symbol (result, (_tmp0 = vala_unresolved_symbol_copy (self->priv->_unresolved_symbol)));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
+	vala_unresolved_type_set_unresolved_symbol (result, _tmp0 = vala_unresolved_symbol_copy (self->priv->_unresolved_symbol));
+	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL));
 	{
-		GeeList* arg_collection;
-		int arg_it;
-		arg_collection = vala_data_type_get_type_arguments (VALA_DATA_TYPE (self));
-		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
+		GeeList* _tmp1;
+		GeeIterator* _tmp2;
+		GeeIterator* arg_it;
+		_tmp1 = NULL;
+		_tmp2 = NULL;
+		arg_it = (_tmp2 = gee_iterable_iterator ((GeeIterable*) (_tmp1 = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)), _tmp2);
+		while (gee_iterator_next (arg_it)) {
 			ValaDataType* arg;
-			arg = ((ValaDataType*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
-			{
-				ValaDataType* _tmp1;
-				_tmp1 = NULL;
-				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp1 = vala_data_type_copy (arg)));
-				(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
-				(arg == NULL ? NULL : (arg = (vala_code_node_unref (arg), NULL)));
-			}
+			ValaDataType* _tmp3;
+			arg = (ValaDataType*) gee_iterator_get (arg_it);
+			_tmp3 = NULL;
+			vala_data_type_add_type_argument ((ValaDataType*) result, _tmp3 = vala_data_type_copy (arg));
+			(_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL));
+			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
-		(arg_collection == NULL ? NULL : (arg_collection = (gee_collection_object_unref (arg_collection), NULL)));
+		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
 	}
-	return VALA_DATA_TYPE (result);
+	return (ValaDataType*) result;
 }
 
 
 static char* vala_unresolved_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaUnresolvedType * self;
-	self = VALA_UNRESOLVED_TYPE (base);
-	g_return_val_if_fail (scope == NULL || VALA_IS_SCOPE (scope), NULL);
-	return vala_code_node_to_string (VALA_CODE_NODE (self->priv->_unresolved_symbol));
+	self = (ValaUnresolvedType*) base;
+	return vala_code_node_to_string ((ValaCodeNode*) self->priv->_unresolved_symbol);
 }
 
 
 ValaUnresolvedSymbol* vala_unresolved_type_get_unresolved_symbol (ValaUnresolvedType* self) {
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_unresolved_symbol;
 }
 
@@ -207,10 +200,10 @@ ValaUnresolvedSymbol* vala_unresolved_type_get_unresolved_symbol (ValaUnresolved
 void vala_unresolved_type_set_unresolved_symbol (ValaUnresolvedType* self, ValaUnresolvedSymbol* value) {
 	ValaUnresolvedSymbol* _tmp2;
 	ValaUnresolvedSymbol* _tmp1;
-	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_unresolved_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_unresolved_symbol == NULL ? NULL : (self->priv->_unresolved_symbol = (vala_code_node_unref (self->priv->_unresolved_symbol), NULL))), _tmp2);
+	self->priv->_unresolved_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_unresolved_symbol == NULL) ? NULL : (self->priv->_unresolved_symbol = (vala_code_node_unref (self->priv->_unresolved_symbol), NULL)), _tmp2);
 }
 
 
@@ -231,7 +224,7 @@ static void vala_unresolved_type_instance_init (ValaUnresolvedType * self) {
 static void vala_unresolved_type_finalize (ValaCodeNode* obj) {
 	ValaUnresolvedType * self;
 	self = VALA_UNRESOLVED_TYPE (obj);
-	(self->priv->_unresolved_symbol == NULL ? NULL : (self->priv->_unresolved_symbol = (vala_code_node_unref (self->priv->_unresolved_symbol), NULL)));
+	(self->priv->_unresolved_symbol == NULL) ? NULL : (self->priv->_unresolved_symbol = (vala_code_node_unref (self->priv->_unresolved_symbol), NULL));
 	VALA_CODE_NODE_CLASS (vala_unresolved_type_parent_class)->finalize (obj);
 }
 
