@@ -29,66 +29,80 @@ enum  {
 	VALA_VOID_TYPE_DUMMY_PROPERTY
 };
 static gboolean vala_void_type_real_stricter (ValaDataType* base, ValaDataType* type2);
-static char* vala_void_type_real_to_string (ValaCodeNode* base);
-static char* vala_void_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
+static char* vala_void_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
+static char* vala_void_type_real_get_cname (ValaDataType* base);
 static ValaDataType* vala_void_type_real_copy (ValaDataType* base);
+static char* vala_void_type_real_get_type_id (ValaDataType* base);
 static gpointer vala_void_type_parent_class = NULL;
 
 
 
-ValaVoidType* vala_void_type_new (void) {
-	ValaVoidType * self;
-	self = g_object_newv (VALA_TYPE_VOID_TYPE, 0, NULL);
+ValaVoidType* vala_void_type_construct (GType object_type) {
+	ValaVoidType* self;
+	self = (ValaVoidType*) g_type_create_instance (object_type);
 	return self;
 }
 
 
+ValaVoidType* vala_void_type_new (void) {
+	return vala_void_type_construct (VALA_TYPE_VOID_TYPE);
+}
+
+
 static gboolean vala_void_type_real_stricter (ValaDataType* base, ValaDataType* type2) {
 	ValaVoidType * self;
-	self = VALA_VOID_TYPE (base);
-	g_return_val_if_fail (type2 == NULL || VALA_IS_DATA_TYPE (type2), FALSE);
+	self = (ValaVoidType*) base;
+	g_return_val_if_fail (type2 != NULL, FALSE);
 	return (VALA_IS_VOID_TYPE (type2));
 }
 
 
-static char* vala_void_type_real_to_string (ValaCodeNode* base) {
+static char* vala_void_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaVoidType * self;
-	self = VALA_VOID_TYPE (base);
+	self = (ValaVoidType*) base;
 	return g_strdup ("void");
 }
 
 
-static char* vala_void_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type) {
+static char* vala_void_type_real_get_cname (ValaDataType* base) {
 	ValaVoidType * self;
-	self = VALA_VOID_TYPE (base);
+	self = (ValaVoidType*) base;
 	return g_strdup ("void");
 }
 
 
 static ValaDataType* vala_void_type_real_copy (ValaDataType* base) {
 	ValaVoidType * self;
-	self = VALA_VOID_TYPE (base);
-	return VALA_DATA_TYPE (vala_void_type_new ());
+	self = (ValaVoidType*) base;
+	return (ValaDataType*) vala_void_type_new ();
+}
+
+
+static char* vala_void_type_real_get_type_id (ValaDataType* base) {
+	ValaVoidType * self;
+	self = (ValaVoidType*) base;
+	return g_strdup ("G_TYPE_NONE");
 }
 
 
 static void vala_void_type_class_init (ValaVoidTypeClass * klass) {
 	vala_void_type_parent_class = g_type_class_peek_parent (klass);
 	VALA_DATA_TYPE_CLASS (klass)->stricter = vala_void_type_real_stricter;
-	VALA_CODE_NODE_CLASS (klass)->to_string = vala_void_type_real_to_string;
+	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_void_type_real_to_qualified_string;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_void_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_void_type_real_copy;
+	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_void_type_real_get_type_id;
 }
 
 
-static void vala_void_type_init (ValaVoidType * self) {
+static void vala_void_type_instance_init (ValaVoidType * self) {
 }
 
 
 GType vala_void_type_get_type (void) {
 	static GType vala_void_type_type_id = 0;
-	if (G_UNLIKELY (vala_void_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaVoidTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_void_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVoidType), 0, (GInstanceInitFunc) vala_void_type_init };
+	if (vala_void_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaVoidTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_void_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVoidType), 0, (GInstanceInitFunc) vala_void_type_instance_init, NULL };
 		vala_void_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaVoidType", &g_define_type_info, 0);
 	}
 	return vala_void_type_type_id;
