@@ -31,9 +31,9 @@
 #include <gee/hashset.h>
 #include <gidlparser.h>
 #include <gidlmodule.h>
-#include <stdio.h>
 #include <gee/collection.h>
 #include <gidlnode.h>
+#include <stdio.h>
 #include <vala/valasourcereference.h>
 #include <vala/valareport.h>
 #include <glib/gstdio.h>
@@ -112,26 +112,26 @@ static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char*
 	char* _tmp2;
 	ValaVAPICheck * self;
 	g_return_val_if_fail (gidlname != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (context), NULL);
+	g_return_val_if_fail (context != NULL, NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	__params_it->name = "gidl";
 	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	vala_value_set_source_file (&__params_it->value, (_tmp1 = vala_source_file_new (context, gidlname, FALSE, NULL)));
+	vala_value_set_source_file (&__params_it->value, _tmp1 = vala_source_file_new (context, gidlname, FALSE, NULL));
 	__params_it++;
-	(_tmp1 == NULL ? NULL : (_tmp1 = (vala_source_file_unref (_tmp1), NULL)));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_context_unref (_tmp0), NULL)));
+	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_file_unref (_tmp1), NULL));
+	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_context_unref (_tmp0), NULL));
 	_tmp5 = NULL;
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	__params_it->name = "metadata";
 	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	vala_value_set_source_file (&__params_it->value, (_tmp5 = vala_source_file_new (context, (_tmp4 = g_strconcat ((_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (gidlname, ((glong) (0))), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2))), ".metadata", NULL)), FALSE, NULL)));
+	vala_value_set_source_file (&__params_it->value, _tmp5 = vala_source_file_new (context, _tmp4 = g_strconcat (_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (gidlname, (glong) 0), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2)), ".metadata", NULL), FALSE, NULL));
 	__params_it++;
-	(_tmp5 == NULL ? NULL : (_tmp5 = (vala_source_file_unref (_tmp5), NULL)));
+	(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_source_file_unref (_tmp5), NULL));
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp3 = (g_free (_tmp3), NULL);
 	__params_it->name = "context";
@@ -154,7 +154,7 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 
 
 static void _g_list_free_g_idl_module_free (GList* self) {
-	g_list_foreach (self, ((GFunc) (g_idl_module_free)), NULL);
+	g_list_foreach (self, (GFunc) g_idl_module_free, NULL);
 	g_list_free (self);
 }
 
@@ -163,32 +163,34 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 	GError * inner_error;
 	GeeList* _tmp0;
 	GeeSet* _tmp1;
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (self != NULL);
 	inner_error = NULL;
 	_tmp0 = NULL;
-	self->priv->_scope = (_tmp0 = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL))), _tmp0);
+	self->priv->_scope = (_tmp0 = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal), (self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL)), _tmp0);
 	_tmp1 = NULL;
-	self->priv->_symbols = (_tmp1 = GEE_SET (gee_hash_set_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_hash, g_str_equal)), (self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL))), _tmp1);
+	self->priv->_symbols = (_tmp1 = (GeeSet*) gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_str_hash, g_str_equal), (self->priv->_symbols == NULL) ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL)), _tmp1);
 	{
+		GList* _tmp2;
+		_tmp2 = g_idl_parse_file (vala_source_file_get_filename (self->priv->_gidl), &inner_error);
+		if (inner_error != NULL) {
+			if (inner_error->domain == G_MARKUP_ERROR) {
+				goto __catch0_g_markup_error;
+			}
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+			g_clear_error (&inner_error);
+		}
 		{
 			GList* module_collection;
 			GList* module_it;
-			module_collection = g_idl_parse_file (vala_source_file_get_filename (self->priv->_gidl), &inner_error);
-			if (inner_error != NULL) {
-				if (inner_error->domain == G_MARKUP_ERROR) {
-					goto __catch0_g_markup_error;
-				}
-				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-				g_clear_error (&inner_error);
-			}
+			module_collection = _tmp2;
 			for (module_it = module_collection; module_it != NULL; module_it = module_it->next) {
 				GIdlModule* module;
-				module = ((GIdlModule*) (module_it->data));
+				module = (GIdlModule*) module_it->data;
 				{
 					vala_vapi_check_parse_members (self, module->name, module->entries);
 				}
 			}
-			(module_collection == NULL ? NULL : (module_collection = (_g_list_free_g_idl_module_free (module_collection), NULL)));
+			(module_collection == NULL) ? NULL : (module_collection = (_g_list_free_g_idl_module_free (module_collection), NULL));
 		}
 	}
 	goto __finally0;
@@ -199,7 +201,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 		inner_error = NULL;
 		{
 			fprintf (stderr, "%s: %s\n", vala_source_file_get_filename (self->priv->_gidl), e->message);
-			(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
+			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 		}
 	}
 	__finally0:
@@ -208,7 +210,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 
 
 static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, const char* separator) {
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (name != NULL);
 	if (NULL != separator) {
 		char* _tmp1;
@@ -218,37 +220,37 @@ static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, c
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		_tmp2 = NULL;
-		fullname = (_tmp2 = g_strconcat ((_tmp1 = g_strconcat ((_tmp0 = vala_vapi_check_get_scope (self)), separator, NULL)), name, NULL), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
-		gee_collection_add (GEE_COLLECTION (self->priv->_symbols), fullname);
+		fullname = (_tmp2 = g_strconcat (_tmp1 = g_strconcat (_tmp0 = vala_vapi_check_get_scope (self), separator, NULL), name, NULL), _tmp1 = (g_free (_tmp1), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
+		gee_collection_add ((GeeCollection*) self->priv->_symbols, fullname);
 		fullname = (g_free (fullname), NULL);
 	} else {
-		gee_collection_add (GEE_COLLECTION (self->priv->_symbols), name);
+		gee_collection_add ((GeeCollection*) self->priv->_symbols, name);
 	}
 }
 
 
 static char* vala_vapi_check_get_scope (ValaVAPICheck* self) {
-	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), NULL);
-	return ((char*) (gee_list_get (((GeeList*) (self->priv->_scope)), gee_collection_get_size (GEE_COLLECTION (self->priv->_scope)) - 1)));
+	g_return_val_if_fail (self != NULL, NULL);
+	return (char*) gee_list_get ((GeeList*) self->priv->_scope, gee_collection_get_size ((GeeCollection*) self->priv->_scope) - 1);
 }
 
 
 static void vala_vapi_check_enter_scope (ValaVAPICheck* self, const char* name) {
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (name != NULL);
-	gee_collection_add (GEE_COLLECTION (self->priv->_scope), name);
+	gee_collection_add ((GeeCollection*) self->priv->_scope, name);
 	vala_vapi_check_add_symbol (self, name, NULL);
 }
 
 
 static void vala_vapi_check_leave_scope (ValaVAPICheck* self) {
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
-	gee_list_remove_at (self->priv->_scope, gee_collection_get_size (GEE_COLLECTION (self->priv->_scope)) - 1);
+	g_return_if_fail (self != NULL);
+	gee_list_remove_at (self->priv->_scope, gee_collection_get_size ((GeeCollection*) self->priv->_scope) - 1);
 }
 
 
 static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members) {
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (members != NULL);
 	vala_vapi_check_enter_scope (self, name);
@@ -258,46 +260,58 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 		node_collection = members;
 		for (node_it = node_collection; node_it != NULL; node_it = node_it->next) {
 			GIdlNode* node;
-			node = ((GIdlNode*) (node_it->data));
+			node = (GIdlNode*) node_it->data;
 			{
-				GIdlNodeTypeId _tmp0;
-				_tmp0 = node->type;
-				if (_tmp0 == G_IDL_NODE_ENUM)
-				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeEnum*) (node)))->gtype_name, (((GIdlNodeEnum*) (node)))->values);
-					break;
-				} while (0); else if (_tmp0 == G_IDL_NODE_FUNCTION)
-				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeFunction*) (node)))->symbol, (((GIdlNodeFunction*) (node)))->parameters);
-					break;
-				} while (0); else if (_tmp0 == G_IDL_NODE_BOXED)
-				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeBoxed*) (node)))->gtype_name, (((GIdlNodeBoxed*) (node)))->members);
-					break;
-				} while (0); else if (_tmp0 == G_IDL_NODE_INTERFACE || _tmp0 == G_IDL_NODE_OBJECT)
-				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeInterface*) (node)))->gtype_name, (((GIdlNodeInterface*) (node)))->members);
-					break;
-				} while (0); else if (_tmp0 == G_IDL_NODE_FIELD || _tmp0 == G_IDL_NODE_PARAM)
-				do {
-					vala_vapi_check_add_symbol (self, node->name, ".");
-					break;
-				} while (0); else if (_tmp0 == G_IDL_NODE_PROPERTY || _tmp0 == G_IDL_NODE_SIGNAL)
-				do {
-					vala_vapi_check_add_symbol (self, node->name, "::");
-					break;
-				} while (0); else if (_tmp0 == G_IDL_NODE_STRUCT)
-				do {
-					vala_vapi_check_parse_members (self, node->name, (((GIdlNodeStruct*) (node)))->members);
-					break;
-				} while (0); else if (_tmp0 == G_IDL_NODE_VALUE || _tmp0 == G_IDL_NODE_VFUNC)
-				do {
-					break;
-				} while (0); else
-				do {
-					g_warning ("valavapicheck.vala:121: TODO: %s: Implement support for type %d nodes", node->name, ((gint) (node->type)));
-					break;
-				} while (0);
+				switch (node->type) {
+					case G_IDL_NODE_ENUM:
+					{
+						vala_vapi_check_parse_members (self, ((GIdlNodeEnum*) node)->gtype_name, ((GIdlNodeEnum*) node)->values);
+						break;
+					}
+					case G_IDL_NODE_FUNCTION:
+					{
+						vala_vapi_check_parse_members (self, ((GIdlNodeFunction*) node)->symbol, ((GIdlNodeFunction*) node)->parameters);
+						break;
+					}
+					case G_IDL_NODE_BOXED:
+					{
+						vala_vapi_check_parse_members (self, ((GIdlNodeBoxed*) node)->gtype_name, ((GIdlNodeBoxed*) node)->members);
+						break;
+					}
+					case G_IDL_NODE_INTERFACE:
+					case G_IDL_NODE_OBJECT:
+					{
+						vala_vapi_check_parse_members (self, ((GIdlNodeInterface*) node)->gtype_name, ((GIdlNodeInterface*) node)->members);
+						break;
+					}
+					case G_IDL_NODE_FIELD:
+					case G_IDL_NODE_PARAM:
+					{
+						vala_vapi_check_add_symbol (self, node->name, ".");
+						break;
+					}
+					case G_IDL_NODE_PROPERTY:
+					case G_IDL_NODE_SIGNAL:
+					{
+						vala_vapi_check_add_symbol (self, node->name, "::");
+						break;
+					}
+					case G_IDL_NODE_STRUCT:
+					{
+						vala_vapi_check_parse_members (self, node->name, ((GIdlNodeStruct*) node)->members);
+						break;
+					}
+					case G_IDL_NODE_VALUE:
+					case G_IDL_NODE_VFUNC:
+					{
+						break;
+					}
+					default:
+					{
+						g_warning ("valavapicheck.vala:121: TODO: %s: Implement support for type %d nodes", node->name, (gint) node->type);
+						break;
+					}
+				}
 			}
 		}
 	}
@@ -307,16 +321,13 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 
 static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 	GError * inner_error;
-	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	inner_error = NULL;
 	{
 		GIOChannel* metafile;
 		char* line;
 		gint lineno;
-		char* _tmp2;
-		GIOStatus _tmp1;
-		char* _tmp0;
-		gint _tmp6;
+		gint _tmp8;
 		metafile = g_io_channel_new_file (vala_source_file_get_filename (self->priv->_metadata), "r", &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
@@ -327,32 +338,54 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		}
 		line = NULL;
 		lineno = 1;
-		_tmp2 = NULL;
-		_tmp0 = NULL;
-		while (G_IO_STATUS_NORMAL == (_tmp1 = g_io_channel_read_line (metafile, &_tmp0, NULL, NULL, &inner_error), line = (_tmp2 = _tmp0, (line = (g_free (line), NULL)), _tmp2), _tmp1)) {
-			char** _tmp3;
+		while (TRUE) {
+			char* _tmp2;
+			GIOStatus _tmp1;
+			char* _tmp0;
+			GIOStatus _tmp3;
+			char** _tmp4;
 			gint tokens_length1;
 			char** tokens;
-			const char* _tmp4;
+			const char* _tmp5;
 			char* symbol;
-			_tmp3 = NULL;
-			tokens = (_tmp3 = g_strsplit (line, " ", 2), tokens_length1 = -1, _tmp3);
+			gboolean _tmp6;
+			_tmp2 = NULL;
+			_tmp0 = NULL;
+			_tmp3 = (_tmp1 = g_io_channel_read_line (metafile, &_tmp0, NULL, NULL, &inner_error), line = (_tmp2 = _tmp0, line = (g_free (line), NULL), _tmp2), _tmp1);
+			if (inner_error != NULL) {
+				if (inner_error->domain == G_FILE_ERROR) {
+					goto __catch1_g_file_error;
+				}
+				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+				g_clear_error (&inner_error);
+			}
+			if (!(G_IO_STATUS_NORMAL == _tmp3)) {
+				break;
+			}
 			_tmp4 = NULL;
-			symbol = (_tmp4 = tokens[0], (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
-			if (strlen (symbol) > 0 && !gee_collection_contains (GEE_COLLECTION (self->priv->_symbols), symbol)) {
+			tokens = (_tmp4 = g_strsplit (line, " ", 2), tokens_length1 = -1, _tmp4);
+			_tmp5 = NULL;
+			symbol = (_tmp5 = tokens[0], (_tmp5 == NULL) ? NULL : g_strdup (_tmp5));
+			_tmp6 = FALSE;
+			if (strlen (symbol) > 0) {
+				_tmp6 = !gee_collection_contains ((GeeCollection*) self->priv->_symbols, symbol);
+			} else {
+				_tmp6 = FALSE;
+			}
+			if (_tmp6) {
 				ValaSourceReference* src;
-				char* _tmp5;
-				src = vala_source_reference_new (self->priv->_metadata, lineno, 1, lineno, ((gint) (g_utf8_strlen (symbol, -1))));
-				_tmp5 = NULL;
-				vala_report_error (src, (_tmp5 = g_strdup_printf ("Symbol `%s' not found", symbol)));
-				_tmp5 = (g_free (_tmp5), NULL);
-				(src == NULL ? NULL : (src = (vala_source_reference_unref (src), NULL)));
+				char* _tmp7;
+				src = vala_source_reference_new (self->priv->_metadata, lineno, 1, lineno, (gint) g_utf8_strlen (symbol, -1));
+				_tmp7 = NULL;
+				vala_report_error (src, _tmp7 = g_strdup_printf ("Symbol `%s' not found", symbol));
+				_tmp7 = (g_free (_tmp7), NULL);
+				(src == NULL) ? NULL : (src = (vala_source_reference_unref (src), NULL));
 			}
 			lineno = lineno + (1);
-			tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) (g_free))), NULL);
+			tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
 			symbol = (g_free (symbol), NULL);
 		}
-		return (_tmp6 = 0, (metafile == NULL ? NULL : (metafile = (g_io_channel_unref (metafile), NULL))), (line = (g_free (line), NULL)), _tmp6);
+		return (_tmp8 = 0, (metafile == NULL) ? NULL : (metafile = (g_io_channel_unref (metafile), NULL)), line = (g_free (line), NULL), _tmp8);
 	}
 	goto __finally1;
 	__catch1_g_file_error:
@@ -361,12 +394,12 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		error = inner_error;
 		inner_error = NULL;
 		{
-			char* _tmp7;
-			gint _tmp8;
-			_tmp7 = NULL;
-			vala_report_error (NULL, (_tmp7 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message)));
-			_tmp7 = (g_free (_tmp7), NULL);
-			return (_tmp8 = 1, (error == NULL ? NULL : (error = (g_error_free (error), NULL))), _tmp8);
+			char* _tmp9;
+			gint _tmp10;
+			_tmp9 = NULL;
+			vala_report_error (NULL, _tmp9 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message));
+			_tmp9 = (g_free (_tmp9), NULL);
+			return (_tmp10 = 1, (error == NULL) ? NULL : (error = (g_error_free (error), NULL)), _tmp10);
 		}
 	}
 	__finally1:
@@ -375,18 +408,18 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 
 
 static gint vala_vapi_check_run (ValaVAPICheck* self) {
-	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	if (!g_file_test (vala_source_file_get_filename (self->priv->_gidl), G_FILE_TEST_IS_REGULAR)) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		vala_report_error (NULL, (_tmp0 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_gidl))));
+		vala_report_error (NULL, _tmp0 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_gidl)));
 		_tmp0 = (g_free (_tmp0), NULL);
 		return 2;
 	}
 	if (!g_file_test (vala_source_file_get_filename (self->priv->_metadata), G_FILE_TEST_IS_REGULAR)) {
 		char* _tmp2;
 		_tmp2 = NULL;
-		vala_report_error (NULL, (_tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_metadata))));
+		vala_report_error (NULL, _tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_metadata)));
 		_tmp2 = (g_free (_tmp2), NULL);
 		return 2;
 	}
@@ -396,21 +429,28 @@ static gint vala_vapi_check_run (ValaVAPICheck* self) {
 
 
 static gint vala_vapi_check_main (char** args, int args_length1) {
-	ValaCodeContext* _tmp2;
-	ValaVAPICheck* _tmp3;
+	gboolean _tmp0;
+	ValaCodeContext* _tmp3;
+	ValaVAPICheck* _tmp4;
 	ValaVAPICheck* vapicheck;
-	gint _tmp4;
-	if (2 != args_length1 || !g_str_has_suffix (args[1], ".gidl")) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		fprintf (stdout, "Usage: %s library.gidl\n", (_tmp0 = g_path_get_basename (args[0])));
-		_tmp0 = (g_free (_tmp0), NULL);
+	gint _tmp5;
+	_tmp0 = FALSE;
+	if (2 != args_length1) {
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = !g_str_has_suffix (args[1], ".gidl");
+	}
+	if (_tmp0) {
+		char* _tmp1;
+		_tmp1 = NULL;
+		fprintf (stdout, "Usage: %s library.gidl\n", _tmp1 = g_path_get_basename (args[0]));
+		_tmp1 = (g_free (_tmp1), NULL);
 		return 2;
 	}
-	_tmp2 = NULL;
 	_tmp3 = NULL;
-	vapicheck = (_tmp3 = vala_vapi_check_new (args[1], (_tmp2 = vala_code_context_new ())), (_tmp2 == NULL ? NULL : (_tmp2 = (vala_code_context_unref (_tmp2), NULL))), _tmp3);
-	return (_tmp4 = vala_vapi_check_run (vapicheck), (vapicheck == NULL ? NULL : (vapicheck = (g_object_unref (vapicheck), NULL))), _tmp4);
+	_tmp4 = NULL;
+	vapicheck = (_tmp4 = vala_vapi_check_new (args[1], _tmp3 = vala_code_context_new ()), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_context_unref (_tmp3), NULL)), _tmp4);
+	return (_tmp5 = vala_vapi_check_run (vapicheck), (vapicheck == NULL) ? NULL : (vapicheck = (g_object_unref (vapicheck), NULL)), _tmp5);
 }
 
 
@@ -421,7 +461,7 @@ int main (int argc, char ** argv) {
 
 
 static ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self) {
-	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_context;
 }
 
@@ -429,16 +469,16 @@ static ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self) {
 static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* value) {
 	ValaCodeContext* _tmp2;
 	ValaCodeContext* _tmp1;
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_context_ref (_tmp1))), (self->priv->_context == NULL ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "context");
+	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_context_ref (_tmp1)), (self->priv->_context == NULL) ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "context");
 }
 
 
 static ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self) {
-	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_gidl;
 }
 
@@ -446,16 +486,16 @@ static ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self) {
 static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value) {
 	ValaSourceFile* _tmp2;
 	ValaSourceFile* _tmp1;
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_gidl = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_file_ref (_tmp1))), (self->priv->_gidl == NULL ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "gidl");
+	self->priv->_gidl = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_source_file_ref (_tmp1)), (self->priv->_gidl == NULL) ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "gidl");
 }
 
 
 static ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self) {
-	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_metadata;
 }
 
@@ -463,11 +503,11 @@ static ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self) {
 static void vala_vapi_check_set_metadata (ValaVAPICheck* self, ValaSourceFile* value) {
 	ValaSourceFile* _tmp2;
 	ValaSourceFile* _tmp1;
-	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_metadata = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_file_ref (_tmp1))), (self->priv->_metadata == NULL ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "metadata");
+	self->priv->_metadata = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_source_file_ref (_tmp1)), (self->priv->_metadata == NULL) ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "metadata");
 }
 
 
@@ -531,11 +571,11 @@ static void vala_vapi_check_instance_init (ValaVAPICheck * self) {
 static void vala_vapi_check_finalize (GObject* obj) {
 	ValaVAPICheck * self;
 	self = VALA_VAPI_CHECK (obj);
-	(self->priv->_context == NULL ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL)));
-	(self->priv->_gidl == NULL ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL)));
-	(self->priv->_metadata == NULL ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL)));
-	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL)));
-	(self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL)));
+	(self->priv->_context == NULL) ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL));
+	(self->priv->_gidl == NULL) ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL));
+	(self->priv->_metadata == NULL) ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL));
+	(self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL));
+	(self->priv->_symbols == NULL) ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL));
 	G_OBJECT_CLASS (vala_vapi_check_parent_class)->finalize (obj);
 }
 
@@ -551,16 +591,16 @@ static GType vala_vapi_check_get_type (void) {
 
 
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
-	if (array != NULL && destroy_func != NULL) {
+	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) (array))[i] != NULL)
-			destroy_func (((gpointer*) (array))[i]);
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) (array))[i]);
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
 		}
 	}
 	g_free (array);
